#
# spec file for package parti
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013-2015 Steffen Winterfeldt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           parti
Version:        2.7
Release:        1.1
Summary:        Show partition table information
License:        GPL-3.0-only
Group:          Hardware/Other
URL:            https://github.com/wfeldt/parti
Source:         %{name}-%{version}.tar.xz
BuildRequires:  libmediacheck-devel
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(uuid)
%if 0%{?suse_version} >= 1500
Requires:       mkisofs
%else
Requires:       cdrkit-cdrtools-compat
%endif

%description
Show partition table information for
* Master Boot Record (MBR) Partition Table
* GUID Partition Table (GPT)
* Apple Partition Map
* El Torito Bootable CD/DVD
* zIPL boot info

It shows the complete information but mostly in uninterpreted form (unlike partitioning tools like fdisk or parted).

So it can be used to verify the data your favorite partitioning tool has actually written.

%prep
%setup -q

%build
%make_build

%install
%make_install

%files
%{_bindir}/parti
%{_bindir}/unify-gpt
%license COPYING
%doc README.md

%changelog
* Wed May  7 2025 wfeldt@opensuse.org
- merge gh#wfeldt/parti#20
- rework unify-gpt
- 2.7
* Wed May  7 2025 wfeldt@opensuse.org
- merge gh#wfeldt/parti#19
- parti.spec: bring spec file to 2024
* Mon Jul  8 2024 wfeldt@opensuse.org
- merge gh#wfeldt/parti#18
- extract parmfile content from s390x el-torito image
- 2.6
* Fri Jul 21 2023 wfeldt@opensuse.org
- merge gh#wfeldt/parti#17
- identify signature block on iso9660 file system
- 2.5
* Mon May 15 2023 wfeldt@opensuse.org
- merge gh#wfeldt/parti#15
- add unify-gpt tool
- update spec file
- 2.4
* Mon Mar 20 2023 wfeldt@opensuse.org
- merge gh#wfeldt/parti#14
- show boot info table information
- 2.3
* Thu Nov 18 2021 wfeldt@opensuse.org
- merge gh#wfeldt/parti#13
- report also empty mbr partition tables
- 2.2
* Wed Nov  3 2021 wfeldt@opensuse.org
- add spec file
- 2.1
* Thu Oct 28 2021 wfeldt@opensuse.org
- merge gh#wfeldt/parti#12
- split into separate parts
- catch and log all disk accesses
- gpt, filesystem, disk json output implemented
- json related functions
- el torito json output
- add mbr json output
- add apple partition table json output
- updated git2log
- refactor code and add JSON output
- 2.0
* Fri Jan  8 2021 wfeldt@opensuse.org
- merge gh#wfeldt/parti#11
- notify about invalid MBR partition entries (bsc#1178691)
- 1.20
* Thu Jul 25 2019 wfeldt@opensuse.org
- merge gh#wfeldt/parti#10
- adjust to isoinfo changes (bsc#1097814)
- 1.19
* Thu Apr 26 2018 wfeldt@opensuse.org
- merge gh#wfeldt/parti#9
- improve doc a bit
- update git2log script to latest version
- reference obs builds
- 1.18
* Wed Apr 25 2018 wfeldt@opensuse.org
- merge gh#wfeldt/parti#8
- extended documentation
- 1.17
* Tue Mar  6 2018 amajer@suse.de
- merge gh#wfeldt/parti#7
- Use standard location for isoinfo binary
- 1.16
* Mon Mar  5 2018 adam.majer@suse.de
- switch to using cdrtools - wodim is to be removed.
- cdrtools.patch: Use isoinfo from standard locations, like installed
  by mkisofs.
* Mon Sep 11 2017 wfeldt@opensuse.org
- merge gh#wfeldt/parti#6
- show more details about extended partition links
- 1.15
* Mon Apr  3 2017 snwint@suse.com
- update docs a bit
- code de-duplication
- re-arrange fat fs output a bit
- parse vfat super block
- 1.14
* Fri Oct 14 2016 snwint@suse.com
- show decoded gpt attribute bits
- 1.13
* Fri Oct 14 2016 snwint@suse.com
- added some GPT GUIDs of linux partitions
- 1.12
* Sun Oct 18 2015 astieger@suse.com
- spec file updates
* Mon Oct 12 2015 snwint@suse.com
- recognize prep partition type
- also show file system uuid
- 1.11
* Wed Oct  7 2015 snwint@suse.com
- gitignore
- README: links to explain the information being handled
- Add link to linux-devtools documentation
- Convert README to Markdown
- 1.10
* Wed Jul 22 2015 snwint@suse.com
- improved zipl parsing
- 1.9
* Fri Jul 17 2015 snwint@suse.com
- support parsing zIPL on scsi devices
- fix endianness issues
- 1.8
* Mon Oct 20 2014 snwint_jenkins@suse.com
- show file name if partition refers to a file
- 1.7
* Fri Oct 17 2014 snwint_jenkins@suse.com
- avoid dependency on cdrkit-cdrtools-compat
- 1.6
* Fri Oct 17 2014 snwint_jenkins@suse.com
- reworked layout and added more info
- 1.5
* Thu Oct 16 2014 snwint_jenkins@suse.com
- show info about filesystems
- 1.4
* Thu Oct 16 2014 snwint_jenkins@suse.com
- show file names in el-torito boot entries
- 1.3
* Thu Oct 16 2014 snwint_jenkins@suse.com
- added 'archive' Makefile target
- updated git2log script
- add bios boot partition type
- 1.2
* Tue Jul 23 2013 snwint@suse.de
- created initial package
